@@ -82,8 +82,8 @@ class PyTestZafiraListener(BaseZafiraListener):
     def __init__(self, state):
         super().__init__(state)
 
-        self.state.CONFIG = "<config><arg unique='false'><key>env</key><value>API " \
-                            + Context.get_gui_parameter(Parameter.BROWSER).upper() + "</value></arg></config>"
+        # self.state.CONFIG = "<config><arg unique='false'><key>env</key><value>API " \
+        #                     + Context.get_gui_parameter(Parameter.BROWSER).upper() + "</value></arg></config>"
 
     @pytest.hookimpl
     def pytest_sessionstart(self, session):
@@ -107,8 +107,9 @@ class PyTestZafiraListener(BaseZafiraListener):
             self.state.test_run = self.state.zc.start_test_run(
                 self.state.job["id"],
                 self.state.test_suite["id"],
-                0,
-                config=self.state.CONFIG
+                0
+                # ,
+                # config=self.state.CONFIG
             ).json()
             self.state.ci_run_id = self.state.test_run.get('ciRunId')
         except Exception as e:
